==> word2vec-0.2.1.jar: META-INF/leiningen/org.bridgei2i/word2vec/README.md <==
# clojure-word2vec

The [word2vec tool](http://code.google.com/p/word2vec/)  by Mikolov et al enables us to 
create word vectors from a dataset containing text data. Unlike a binary present/absent representation
used by a bag-of-words, these word vectors can be used to compare 2 words and see if they are related.

This is a Clojure wrapper of Java implementation of word2vec [available here] (https://github.com/medallia/Word2VecJava).

## Installation

To include word2vec, add the following to your :dependencies section of project.clj

[![Clojars Project](http://clojars.org/org.bridgei2i/word2vec/latest-version.svg)]

## Usage

First import clojure-word2vec.core into your namespace

```clojure
(ns clojure-word2vec.examples
  (:require [clojure-word2vec.core :refer :all]
            [clojure.java.io :as io]))
```

Download a text corpus and place it in the resources folder. 
Here we'll download James Joyce's Ulysses from [Project Gutenberg](https://www.gutenberg.org/ebooks/4300.txt.utf-8).


```clojure
(def data
  (create-input-format "ulysses.txt"))
```

Create the model and train it, using the default hyperparameters
```clojure
(def model (word2vec data))
```

The hyper parameters can be specified as arguments to word2vec. 

```clojure
(def model (word2vec data :window-size 15)
```

Find the closest words to a given word

```clojure
(get-matches model "woman")
```

### A longer introduction is available in the [docs](https://github.com/Bridgei2i/clojure-word2vec/blob/master/doc/intro.md) .

## License

Copyright © 2015 Bridgei2i 

Distributed under the Eclipse Public License version 1.0.

==> word2vec-0.2.2.jar: META-INF/leiningen/org.bridgei2i/word2vec/README.md <==
# clojure-word2vec

The [word2vec tool](http://code.google.com/p/word2vec/)  by Mikolov et al enables us to 
create word vectors from a dataset containing text data. Unlike a binary present/absent representation
used by a bag-of-words, these word vectors can be used to compare 2 words and see if they are related.

This is a Clojure wrapper of Java implementation of word2vec [available here] (https://github.com/medallia/Word2VecJava).

## Installation

To include word2vec, add the following to your :dependencies section of project.clj

[![Clojars Project](http://clojars.org/org.bridgei2i/word2vec/latest-version.svg)]

## Usage

First import clojure-word2vec.core into your namespace

```clojure
(ns clojure-word2vec.examples
  (:require [clojure-word2vec.core :refer :all]
            [clojure.java.io :as io]))
```

Download a text corpus and place it in the resources folder. 
Here we'll download James Joyce's Ulysses from [Project Gutenberg](https://www.gutenberg.org/ebooks/4300.txt.utf-8).


```clojure
(def data
  (create-input-format "path/to/ulysses.txt"))
```

Create the model and train it, using the default hyperparameters
```clojure
(def model (word2vec data))
```

The hyper parameters can be specified as arguments to word2vec. 

```clojure
(def model (word2vec data :window-size 15)
```

Find the closest words to a given word

```clojure
(get-matches model "woman")
```

### A longer introduction is available in the [docs](https://github.com/shark8me/clojure-word2vec/blob/master/doc/intro.md) .

## License

Copyright © 2015 Bridgei2i 

Distributed under the Eclipse Public License version 1.0.
